@@ -1,5 +1,6 @@
 var NAVTREEINDEX16 =
 {
+"page_module_access.html":[3,0],
 "page_module_adapter.html":[3,1],
 "page_module_avb.html":[3,2],
 "page_module_client_device.html":[3,3],
@@ -248,6 +249,5 @@ var NAVTREEINDEX16 =
 "structpw__client__events.html#a0ceb2ae8884ca4a30bae720198410075":[8,3,3,2,0],
 "structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254":[8,3,3,2,1],
 "structpw__client__events.html#af685647fe57d1a9dba2a0d89d32aae39":[8,3,3,2,2],
-"structpw__client__info.html":[8,3,3,1],
-"structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21":[8,3,3,1,0]
+"structpw__client__info.html":[8,3,3,1]
 };
